@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-28'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -123,9 +123,12 @@ sub gen_help {
             my $cmdline = $eg->{cmdline};
             $cmdline =~ s/\[\[prog\]\]/$progname/;
             push @help, "\n" if $eg->{summary} && $i > 1;
-            push @help, "  $eg->{summary}:\n" if $eg->{summary};
+            if ($eg->{summary}) {
+                push @help, "  $eg->{summary}:\n";
+            } else {
+                push @help, "\n";
+            }
             push @help, "  % $cmdline\n";
-            push @help, "\n" if $eg->{summary} && $i < @$egs;
         }
     }
 
@@ -237,7 +240,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2016-09-26.
+This document describes version 0.11 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2016-09-28.
 
 =head1 DESCRIPTION
 
